reuse-spdx - reuse 6.1.2 documentation

Skip to content
Back to top
View this page

# reuse-spdx

## Synopsis

reuse spdx [options]

## Description

reuse-spdx generates an SPDX bill of materials for the project.

The bill of materials is output to STDOUT.

## Options

-o, --output FILE

  Write the bill of materials to a file instead of writing it to STDOUT.

--add-license-concluded

  Instead of writing ‘NOASSERTION’ to LicenseConcluded, write an expression that is the logical equivalent of AND-ing all found expressions.

--creator-person

  Name of the creator (person) of the bill of materials.

--creator-organization

  Name of the creator (organization) of the bill of materials.

--help

  Display help and exit.